---
title: 사업자번호가 바뀌면 어떻게 하나요?
category: 자주 묻는 질문 (일반 문의) > 일반 문의 > 자주 묻는 질문
seo:
  title: 사업자번호가 바뀌면 어떻게 하나요?
  description: >-
    결제대행사와의 계약은 사업자번호를 기준으로 이루어집니다. 사업자번호 변경 시에는, 결제대행사의 정책에 따라 포트원을 통해 결제대행사와의
    계약을 신규로 진행해주시기 바랍니다.
  keywords:
    - 계약절차
tags:
  - 계약절차
pgCompanies:
  - 공통
searchTags:
  - 양도양수
  - 폐업
  - 사업자변경
  - 법인변경
  - 개인법인변경
  - 사업자번호
  - 사업자번호 변경
datetime: 2024-01-25T15:00:00.000Z
---

사업자의 ①양도양수 ②법인사업자로의 전환 ③폐업 후 신규 서비스 등록 등 다양한 사유로 사업자번호가 변경되는 경우가 존재할텐데요! 기본적으로 결제대행사와의 계약은 사업자번호를 기준으로 이루어집니다.

따라서 사업자번호가 변경된다면, 결제대행사의 정책에 따라 포트원을 통해 결제대행사와의 계약을 신규로 진행해주셔야 합니다.

신규 계약과 동시에 기존 서비스가 정상 운영되어야 하는 경우 연동 과정을 세밀히 신경써주셔야 하므로 관련 가이드를 자세히 참고해주세요.

<Callout content="" icon="" title="사업자 양도양수(변경) 절차 바로가기 ↗" />
